"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get = void 0;
const Service_1 = require("../../Service");
const _1 = require("../../_");
function escapeXMLSpecialChars(str) {
    return str.replace(/&/g, "&amp;")
        .replace(/</g, "&lt;")
        .replace(/>/g, "&gt;")
        .replace(/"/g, "&quot;")
        .replace(/'/g, "&apos;");
}
function getDateTime(time) {
    return new Date(time).toISOString()
        .replace(/\..+$/, "")
        .replace(/[-:T]/g, "");
}
const get = async (req, res) => {
    const apiRoot = `${req.protocol}://${req.headers.host}/api`;
    const services = [..._1.default.service.items];
    services.sort((a, b) => a.getOrder() - b.getOrder());
    let x = `<?xml version="1.0" encoding="UTF-8"?>\n`;
    x += `<!DOCTYPE tv SYSTEM "xmltv.dtd">\n`;
    x += `<tv source-info-name="Mirakurun">\n`;
    const countMap = new Map();
    for (const service of services) {
        if (service.type !== 1) {
            continue;
        }
        const mainNum = service.remoteControlKeyId || service.serviceId;
        if (countMap.has(mainNum)) {
            countMap.set(mainNum, countMap.get(mainNum) + 1);
        }
        else {
            countMap.set(mainNum, 1);
        }
        const subNum = countMap.get(mainNum);
        x += `<channel id="${service.id}">\n`;
        x += `<display-name>${escapeXMLSpecialChars(service.name)}</display-name>\n`;
        x += `<display-name>${mainNum}.${subNum}</display-name>\n`;
        if (await Service_1.default.isLogoDataExists(service.networkId, service.logoId)) {
            x += `<icon src="${apiRoot}/services/${service.id}/logo" />`;
        }
        x += `</channel>\n`;
    }
    for (const program of _1.default.program.itemMap.values()) {
        const service = _1.default.service.get(program.networkId, program.serviceId);
        if (service === null) {
            continue;
        }
        x += `<programme start="${getDateTime(program.startAt)}" stop="${getDateTime(program.startAt + program.duration)}" channel="${service.id}">\n`;
        x += `<title>${escapeXMLSpecialChars(program.name || "")}</title>\n`;
        x += `<desc>${escapeXMLSpecialChars(program.description || "")}</desc>\n`;
        x += `</programme>\n`;
    }
    x += `</tv>`;
    res.setHeader("Content-Type", "text/xml; charset=utf-8");
    res.status(200);
    res.end(x);
};
exports.get = get;
exports.get.apiDoc = {
    tags: ["iptv"],
    summary: "IPTV - XMLTV EPG Data",
    produces: ["text/xml"],
    responses: {
        200: {
            description: "OK"
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};
//# sourceMappingURL=xmltv.js.map